@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -294,7 +294,8 @@ sub DynamicFieldGet {
     }
 
     # get yaml object
-    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
+    my $YAMLObject      = $Kernel::OM->Get('Kernel::System::YAML');
+    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
 
     my %Data;
     while ( my @Data = $DBObject->FetchrowArray() ) {
@@ -1694,32 +1695,16 @@ sub _DynamicFieldReorder {
 
 =head2 _SanitizeConfig()
 
-This function cleans up the config:
+Currently only removes JavaScript code from configured regular expression error messages.
 
-Removes JavaScript code from configured regular expression error messages:
-
-    my $Success = $DynamicFieldObject->_SanitizeConfig(
+    $DynamicFieldObject->_SanitizeConfig(
 
         # 'Config' part of a dynamic field config hash returned by DynamicFieldGet()
         # or given to DynamicFieldAdd() and -Update()
         Config => $Config,
     );
 
-
-Removes reserved keywords in link configuration:
-
-    my $Success = $DynamicFieldObject->_SanitizeConfig(
-        Config => {
-            Link => 'https://www.znuny.org/[% Data.Link %]/[% Data.LinkPreview %]/[% Data.Title %]/[% Data.Value %]'
-        },
-    );
-
-    $Config->{Link} = 'https://www.znuny.org////';
-
-
-Return:
-
-    my $Success = 1;
+    Returns 1.
 
 =cut
 
@@ -1740,7 +1725,13 @@ sub _SanitizeConfig {
         return;
     }
 
-    return if !IsHashRefWithData( $Param{Config} );
+    if ( !IsHashRefWithData( $Param{Config} ) ) {
+        $LogObject->Log(
+            Priority => 'error',
+            Message  => "Parameter 'Config' must be a hash ref with data!",
+        );
+        return;
+    }
 
     # Remove JavaScript, etc. from regex error messages.
     # This prevents execution of arbitrary JavaScript when showing
@@ -1766,13 +1757,6 @@ sub _SanitizeConfig {
         $RegExConfig->{ErrorMessage} = $SafeRegExErrorMessage{String} // '';
     }
 
-    my @ReservedKeywords = (qw(Link LinkPreview Title Value));
-    if ( $Param{Config}->{Link} ) {
-        for my $Keyword (@ReservedKeywords) {
-            $Param{Config}->{Link} =~ s{\[\% Data\.$Keyword \%\]}{}g;
-        }
-    }
-
     return 1;
 }
 
